@@ -15,7 +15,10 @@
 #'  \item For every value where \code{cond(x)==NA} / \code{cond==NA},
 #'  function \code{other(x)} is run or scalar \code{other} is returned. \cr
 #' }
-#'
+#' 
+#' For a more \code{ifelse}-like function where
+#' \code{yes}, \code{no}, and \code{other} are vectors,
+#' see \code{kit::}\link[kit]{iif}.
 #'
 #' @param x a vector, matrix, or array.
 #' @param cond either an object of class \code{logical} with the same length as \code{x}, \cr
@@ -42,9 +45,9 @@
 #' @details
 #' Be careful with coercion! For example the following code:
 #'
-#' ```{r echo=TRUE, eval = FALSE}
+#' ```{r echo = TRUE, eval = FALSE}
 #' x <- c("a", "b")
-#' transform_if(x, \(x)x=="a", as.numeric, as.logical)
+#' transform_if(x, \(x) x == "a", as.numeric, as.logical)
 #' ```
 #' returns:
 #'
@@ -60,18 +63,18 @@
 #' The transformed vector, matrix, or array (attributes are conserved).
 #'
 #'
-#' @seealso [tinycodet_dry()]
+#' @seealso \link{tinycodet_dry}
 #'
 #' @examples
 #' x <- c(-10:9, NA, NA)
-#' object <- matrix(x, ncol=2)
+#' object <- matrix(x, ncol = 2)
 #' attr(object, "helloworld") <- "helloworld"
 #' print(object)
 #' y <- 0
 #' z <- 1000
 #'
-#' object |> transform_if(\(x)x>y, log, \(x)x^2, \(x)-z)
-#' object |> transform_if(object > y, log, \(x)x^2, -z) # same as previous line
+#' object |> transform_if(\(x) x > y, log, \(x) x^2, \(x) -z)
+#' object |> transform_if(object > y, log, \(x) x^2, -z) # same as previous line
 #'
 
 
@@ -99,11 +102,9 @@ transform_if <- function(
     stop("improper `other` given")
   }
 
-  y <- x
-
   # make & check cond:
   if (is.function(cond)) {
-    cond <- cond(y)
+    cond <- cond(x)
   }
   if (!is.logical(cond)) {
     stop(paste0(
@@ -123,28 +124,21 @@ transform_if <- function(
   }
 
   # make transformations:
-  if(any(cond)) {
-    ind_T <- which(cond)
-    y[ind_T] <- .internal_transform_if(yes, y, ind_T)
-  }
-  if(any(!cond)) {
-    ind_F <- which(!cond)
-    y[ind_F] <- .internal_transform_if(no, y, ind_F)
-  }
-  if(anyNA(cond)) {
-    ind_NA <- which(is.na(cond))
-    y[ind_NA] <- .internal_transform_if(other, y, ind_NA)
-  }
+  ind_T <- which(cond)
+  x[ind_T] <- .internal_transform_if(yes, x, ind_T)
+  ind_F <- which(!cond)
+  x[ind_F] <- .internal_transform_if(no, x, ind_F)
+  ind_NA <- which(is.na(cond))
+  x[ind_NA] <- .internal_transform_if(other, x, ind_NA)
 
-  return(y)
+  return(x)
 }
 
 
 .internal_transform_if <- function(f, y, ind) {
   if(is.function(f)) {
     return(f(y[ind]))
-  }
-  else {
+  } else {
     return(f)
   }
 }
